==> cloud-5.0.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/pages/openstack/instance/OpenStackInstanceConsoleOutputPage.tsx <==
import ErrorAlert from 'atoms/ErrorAlert';
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import EntityData from 'model/EntityData';
import EntityFormRecord from 'model/EntityFormRecord';
import Breadcrumbs from 'organisms/Breadcrumbs';
import EntityFormPanel from 'organisms/EntityFormPanel';
import PageTitle from 'organisms/PageTitle';
import SideBar from 'organisms/SideBar';
import { useEffect, useState } from 'react';
import { Col, Container, Form, Row } from 'react-bootstrap';
import { Link, useParams } from 'react-router-dom';

/**
 * Information on the acion panel.
 */
const actionPanel: EntityFormRecord = {
  type: 'panel',
  panelName: 'Actions',
  keyValueRecords: [
    {
      type: 'select-local', labelName: 'Number of lines', name: 'lines', defaultValue: '150', value: [
        { name: '50', labelName: '50' },
        { name: '100', labelName: '100' },
        { name: '150', labelName: '150' },
        { name: 'ALL', labelName: 'ALL Lines' },
      ], required: true
    },
  ]
}

/**
 * Custom Hooks for entity data.
 *
 * @param entityId The entity's ID.
 */
const useEntityData = (entityId: string) => {

  const { getJsonData } = useDrupalJsonApi();
  const [entityData, setEntityData] = useState<EntityData | undefined>();
  const [isLoading, setLoading] = useState(true);

  if (isLoading) {
    setLoading(false);
    const entityTypeId = 'openstack_instance';
    const url = `/jsonapi/${entityTypeId}/${entityTypeId}?filter[drupal_internal__id]=${entityId}`;
    getJsonData<{ data: EntityData[] }>(url).then((result) => {
      if (result.data.length >= 1) {
        setEntityData(result.data[0]);
      }
    });
  }

  return {
    entityData,
  }

}

/**
 * The console output page of OpenStack Instance.
 */
const OpenStackInstanceConsoleOutputPage = () => {

  const params: {
    cloudServiceProvider: string,
    cloudContext: string,
    entityName: string,
    entityId: string,
    action: string
  } = useParams();

  const { getJsonData } = useDrupalJsonApi();
  const { entityData } = useEntityData(params.entityId);
  const [formData, setFormData] = useState<Record<string, any>>({
    lines: '150',
  });
  const [consoleOutput, setConsoleOutput] = useState('');
  const [isLoading, setLoading] = useState(true);
  const [errorMessage, setErrorMessage] = useState('');

  if (isLoading) {
    getJsonData<{ result: string, log: string }>(`/cloud_dashboard/openstack/${params.cloudContext}/instance/${params.entityId}/console_output`).then((res) => {
      setConsoleOutput(res.log);
      setLoading(false);
    }).catch(() => {
      setErrorMessage('Console output could not be read.');
    });
  }

  const filteredConsoleOutput = formData['lines'] === 'ALL'
    ? consoleOutput
    : consoleOutput.split('\n').slice(-parseInt(formData['lines'])).join('\n');

  useEffect(() => {
    console.group('FormData');
    console.log(formData);
    console.groupEnd();
  }, [formData]);

  useEffect(() => {
    console.log(entityData);
  }, [entityData]);

  const baseUrl = `/openstack/${params.cloudContext}/instance/${params.entityId}`;

  return <>
    <PageTitle />
    <Breadcrumbs />
    <SideBar />
    <nav className="tabs">
      <div>
        <ul className="nav nav-tabs">
          <li>
            <Link to={baseUrl}
              className="active is-active ripple-effect">
              View
            </Link>
          </li>
          <li>
            <Link to={`${baseUrl}/edit`}
              className="active is-active ripple-effect">
              Edit
            </Link>
          </li>
          <li className="active">
            <Link to={`${baseUrl}/console_output`}
              className="active is-active ripple-effect">
              Console output
            </Link>
          </li>
          <li>
            <Link to={`${baseUrl}/delete`}
              className="active is-active ripple-effect">
              Delete
            </Link>
          </li>
        </ul>
      </div>
    </nav>
    <Container fluid className="px-0">
      <Row>
        <Col>
          <Form>
            <ErrorAlert message={errorMessage} />
            {
              entityData !== undefined && entityData.attributes['instance_state'] !== 'running'
                ? <Form.Group>
                  <Form.Label>
                    Console output cannot be displayed when an instance is stopped.
                  </Form.Label>
                </Form.Group>
                : <>
                  <EntityFormPanel
                    cloudServiceProvider={params.cloudServiceProvider}
                    cloudContext={params.cloudContext}
                    entityName={params.entityName}
                    actionType={params.action}
                    entityRecord={actionPanel}
                    formData={formData}
                    setFormData={setFormData} />
                  <pre style={{ 'backgroundColor': 'black', 'color': 'white' }}>
                    <span>
                      {filteredConsoleOutput}
                    </span>
                  </pre>
                </>
            }
          </Form>
        </Col>
      </Row>
    </Container>
  </>;

}

export default OpenStackInstanceConsoleOutputPage;

==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/pages/openstack/instance/OpenStackInstanceConsoleOutputPage.tsx <==
import ErrorAlert from 'atoms/ErrorAlert';
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import EntityData from 'model/EntityData';
import EntityFormRecord from 'model/EntityFormRecord';
import Breadcrumbs from 'organisms/Breadcrumbs';
import EntityFormPanel from 'organisms/EntityFormPanel';
import PageTitle from 'organisms/PageTitle';
import SideBar from 'organisms/SideBar';
import { useEffect, useState } from 'react';
import { Col, Container, Form, Row } from 'react-bootstrap';
import { Link, useParams } from 'react-router-dom';

/**
 * Information on the acion panel.
 */
const actionPanel: EntityFormRecord = {
  type: 'panel',
  panelName: 'Actions',
  keyValueRecords: [
    {
      type: 'select-local', labelName: 'Number of lines', name: 'lines', defaultValue: '150', value: [
        { name: '50', labelName: '50' },
        { name: '100', labelName: '100' },
        { name: '150', labelName: '150' },
        { name: 'ALL', labelName: 'ALL Lines' },
      ], required: true
    },
  ]
}

/**
 * Custom Hooks for entity data.
 *
 * @param entityId The entity's ID.
 */
const useEntityData = (entityId: string) => {

  const { getJsonData } = useDrupalJsonApi();
  const [entityData, setEntityData] = useState<EntityData | undefined>();
  const [isLoading, setLoading] = useState(true);

  if (isLoading) {
    setLoading(false);
    const entityTypeId = 'openstack_instance';
    const url = `/jsonapi/${entityTypeId}/${entityTypeId}?filter[drupal_internal__id]=${entityId}`;
    getJsonData<{ data: EntityData[] }>(url).then((result) => {
      if (result.data.length >= 1) {
        setEntityData(result.data[0]);
      }
    });
  }

  return {
    entityData,
  }

}

/**
 * The console output page of OpenStack Instance.
 */
const OpenStackInstanceConsoleOutputPage = () => {

  const params: {
    cloudServiceProvider: string,
    cloudContext: string,
    entityName: string,
    entityId: string,
    action: string
  } = useParams();

  const { getJsonData } = useDrupalJsonApi();
  const { entityData } = useEntityData(params.entityId);
  const [formData, setFormData] = useState<Record<string, any>>({
    lines: '150',
  });
  const [consoleOutput, setConsoleOutput] = useState('');
  const [isLoading, setLoading] = useState(true);
  const [errorMessage, setErrorMessage] = useState('');

  if (isLoading) {
    getJsonData<{ result: string, log: string }>(`/cloud_dashboard/openstack/${params.cloudContext}/instance/${params.entityId}/console_output`).then((res) => {
      setConsoleOutput(res.log);
      setLoading(false);
    }).catch(() => {
      setErrorMessage('Console output could not be read.');
    });
  }

  const filteredConsoleOutput = formData['lines'] === 'ALL'
    ? consoleOutput
    : consoleOutput.split('\n').slice(-parseInt(formData['lines'])).join('\n');

  useEffect(() => {
    console.group('FormData');
    console.log(formData);
    console.groupEnd();
  }, [formData]);

  const baseUrl = `/openstack/${params.cloudContext}/instance/${params.entityId}`;

  return <>
    <PageTitle />
    <Breadcrumbs />
    <SideBar />
    <nav className="tabs">
      <div>
        <ul className="nav nav-tabs" id="tab_wrap">
          <li>
            <Link to={baseUrl}
              className="active is-active ripple-effect">
              View
            </Link>
          </li>
          <li>
            <Link to={`${baseUrl}/edit`}
              className="active is-active ripple-effect">
              Edit
            </Link>
          </li>
          <li className="active">
            <Link to={`${baseUrl}/console_output`}
              className="active is-active ripple-effect">
              Console output
            </Link>
          </li>
          <li>
            <Link to={`${baseUrl}/delete`}
              className="active is-active ripple-effect">
              Delete
            </Link>
          </li>
        </ul>
      </div>
    </nav>
    <Container fluid className="px-0">
      <Row>
        <Col>
          <Form>
            <ErrorAlert message={errorMessage} />
            {
              entityData !== undefined && entityData.attributes['instance_state'] !== 'running'
                ? <Form.Group>
                  <Form.Label>
                    Console output cannot be displayed when an instance is stopped.
                  </Form.Label>
                </Form.Group>
                : <>
                  <EntityFormPanel
                    cloudServiceProvider={params.cloudServiceProvider}
                    cloudContext={params.cloudContext}
                    entityName={params.entityName}
                    actionType={params.action}
                    entityRecord={actionPanel}
                    formData={formData}
                    setFormData={setFormData} />
                  <pre style={{ 'backgroundColor': 'black', 'color': 'white' }}>
                    <span>
                      {filteredConsoleOutput}
                    </span>
                  </pre>
                </>
            }
          </Form>
        </Col>
      </Row>
    </Container>
  </>;

}

export default OpenStackInstanceConsoleOutputPage;
